Class: Decidim::Surveys::SurveyCell

Inherits:
ViewModel
  • Object
show all
Includes:
Cell::ViewModel::Partial
Defined in:
app/cells/decidim/surveys/survey_cell.rb

Overview

This cell renders the proposal card for an instance of a Survey the default size is the Medium Card (:m)

Instance Method Summary collapse

Instance Method Details

#showObject



10
11
12
# File 'app/cells/decidim/surveys/survey_cell.rb', line 10

def show
  cell card_size, model, options
end